@@ -1,10 +1,10 @@
 """
 Extend :class:`hammurabi.rules.base.Rule` to handle parsed content manipulations dictionaries.
 Standalone these rules are not useful, but they are very handy when files should be manipulated
-like YAML or JSON which will be parsed as dict.
+like Yaml or Json which will be parsed as dict.
 
-These rules are intentionally not exported directly through hammurabi as it is done for YAML or
-JSON rules. The reason, as it is mentioned above, these rules are not standalone rules. Also, it
+These rules are intentionally not exported directly through hammurabi as it is done for Yaml or
+Json rules. The reason, as it is mentioned above, these rules are not standalone rules. Also, it
 is intentional that these rules are not represented in the documentation's `Rules section`_.
 
 .. _`Rules section`: https://hammurabi.readthedocs.io/en/latest/rules.html
@@ -14,7 +14,7 @@ from abc import ABC, abstractmethod
 from copy import deepcopy
 import logging
 from pathlib import Path
-from typing import Any, Callable, Dict, Hashable, List, Optional, Union
+from typing import Any, Callable, Dict, Hashable, List, MutableMapping, Optional, Union
 
 from hammurabi.rules.common import SinglePathRule
 from hammurabi.rules.mixins import SelectorMixin
@@ -24,8 +24,8 @@ class SinglePathDictParsedRule(SinglePathRule, SelectorMixin):
     """
     Extend :class:`hammurabi.rules.base.Rule` to handle parsed content
     manipulations dictionaries. Standalone this rule is not useful, but
-    it is very handy when files should be manipulated like YAML or
-    JSON which will be parsed as dict. This rule ensures that the implementation
+    it is very handy when files should be manipulated like Yaml or
+    Json which will be parsed as dict. This rule ensures that the implementation
     will be the same for these rules, so the maintenance cost and effort
     is reduced.
 
@@ -40,7 +40,7 @@ class SinglePathDictParsedRule(SinglePathRule, SelectorMixin):
         name: str,
         path: Optional[Path] = None,
         key: str = "",
-        loader: Callable[[Any], Dict[str, Any]] = dict,
+        loader: Callable[[Any], MutableMapping[str, Any]] = dict,
         **kwargs,
     ) -> None:
         self.selector = self.validate(key, required=True)
@@ -69,7 +69,7 @@ class SinglePathDictParsedRule(SinglePathRule, SelectorMixin):
         does nothing.
 
         :param data: The modified data
-        :type data: :class:``hammurabi.rules.mixins.Any`
+        :type data: :class:``hammurabi.rules.mixins.Any``
 
         :param delete: Indicate if the key should be deleted
         :type delete: bool
@@ -123,10 +123,17 @@ class DictKeyExists(SinglePathDictParsedRule, ABC):
         >>> pillar = Pillar()
         >>> pillar.register(example_law)
 
+    .. note::
+
+        The difference between KeyExists and ValueExists rules is the approach and the
+        possibilities. While KeyExists is able to create values if provided, ValueExists
+        rules are not able to create keys if any of the missing. KeyExists ``value`` parameter
+        is a shorthand for creating a key and then adding a value to that key.
+
     .. warning::
 
         Compared to :mod:`hammurabi.rules.text.LineExists`, this rule is NOT able to add a
-        key before or after a target.
+        key before or after a match.
     """
 
     def __init__(
@@ -337,6 +344,13 @@ class DictValueExists(SinglePathDictParsedRule, ABC):
         >>> pillar = Pillar()
         >>> pillar.register(example_law)
 
+    .. note::
+
+        The difference between KeyExists and ValueExists rules is the approach and the
+        possibilities. While KeyExists is able to create values if provided, ValueExists
+        rules are not able to create keys if any of the missing. KeyExists ``value`` parameter
+        is a shorthand for creating a key and then adding a value to that key.
+
     .. warning::
 
         Since the value can be anything from ``None`` to a list of lists, and
